---
title: <span class="badge object-type-scalar"></span> OpsPerSecond
---
# <span class="badge object-type-scalar"></span> OpsPerSecond

Throughput: ops/sec (ops)

## Definition

```python
# Throughput: ops/sec (ops)
OpsPerSecond: typing.Literal["ops"] = "ops"
```
